package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TdPropertyNetMapper;
import com.ruoyi.system.domain.TdPropertyNet;
import com.ruoyi.system.service.ITdPropertyNetService;
import com.ruoyi.common.core.text.Convert;

/**
 * 涉密网络设备Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-05-09
 */
@Service
public class TdPropertyNetServiceImpl implements ITdPropertyNetService 
{
    @Autowired
    private TdPropertyNetMapper tdPropertyNetMapper;

    /**
     * 查询涉密网络设备
     * 
     * @param netId 涉密网络设备主键
     * @return 涉密网络设备
     */
    @Override
    public TdPropertyNet selectTdPropertyNetByNetId(String netId)
    {
        return tdPropertyNetMapper.selectTdPropertyNetByNetId(netId);
    }

    /**
     * 查询涉密网络设备列表
     * 
     * @param tdPropertyNet 涉密网络设备
     * @return 涉密网络设备
     */
    @Override
    public List<TdPropertyNet> selectTdPropertyNetList(TdPropertyNet tdPropertyNet)
    {
        return tdPropertyNetMapper.selectTdPropertyNetList(tdPropertyNet);
    }

    /**
     * 新增涉密网络设备
     * 
     * @param tdPropertyNet 涉密网络设备
     * @return 结果
     */
    @Override
    public int insertTdPropertyNet(TdPropertyNet tdPropertyNet)
    {
        return tdPropertyNetMapper.insertTdPropertyNet(tdPropertyNet);
    }

    /**
     * 修改涉密网络设备
     * 
     * @param tdPropertyNet 涉密网络设备
     * @return 结果
     */
    @Override
    public int updateTdPropertyNet(TdPropertyNet tdPropertyNet)
    {
        return tdPropertyNetMapper.updateTdPropertyNet(tdPropertyNet);
    }

    /**
     * 批量删除涉密网络设备
     * 
     * @param netIds 需要删除的涉密网络设备主键
     * @return 结果
     */
    @Override
    public int deleteTdPropertyNetByNetIds(String netIds)
    {
        return tdPropertyNetMapper.deleteTdPropertyNetByNetIds(Convert.toStrArray(netIds));
    }

    /**
     * 删除涉密网络设备信息
     * 
     * @param netId 涉密网络设备主键
     * @return 结果
     */
    @Override
    public int deleteTdPropertyNetByNetId(String netId)
    {
        return tdPropertyNetMapper.deleteTdPropertyNetByNetId(netId);
    }
}
